@@ -9,7 +9,7 @@ import time
 from django import forms
 import mysql.connector as sql
 from datasource import MySQLDataSource, PgSQLDataSource
-from context import DBConnection, DBContext
+from context import DBConnection, DBContext, DBVendor
 from converters import RSDConverter, AlephConverter, OrangeConverter, TreeLikerConverter, PrdFctConverter
 from mapper import domain_map
 
@@ -19,13 +19,13 @@ def database_connect(input_dict):
     password = str(input_dict['password'])
     host = str(input_dict['host'])
     db = str(input_dict['database'])
-    vendor = str(input_dict['vendor'])
+    vendor = str(input_dict.get('vendor', DBVendor.MySQL))
     dbcon = DBConnection(user, password, host, db, vendor=vendor)
-    return {'connection' : dbcon}
+    return {'connection': dbcon}
 
 
 def database_db_context(input_dict):
-    return {'context' : None}
+    return {'context': None}
 
 
 def database_db_context_finished(postdata, input_dict, output_dict):
@@ -33,7 +33,7 @@ def database_db_context_finished(postdata, input_dict, output_dict):
     find_con = input_dict['find_connections'] == 'true'
     context = DBContext(con, find_connections=find_con)
     _update_context(context, postdata)
-    return {'context' : context}
+    return {'context': context}
 
 
 def _update_context(context, postdata):
@@ -57,7 +57,9 @@ def _update_context(context, postdata):
     for table in context.tables:
         context.cols[table] = postdata.get('%s_columns%s' % (table, widget_id), [])
         if table == context.target_table and context.target_att not in context.cols[table]:
-            raise Exception('The selected target attribute ("%s") is not among the columns selected for the target table ("%s").' % (context.target_att, context.target_table))
+            raise Exception(
+                'The selected target attribute ("%s") is not among the columns selected for the target table ("%s").' % (
+                context.target_att, context.target_table))
     if context.in_memory:
         context.orng_tables = context.read_into_orange()
 
@@ -65,7 +67,7 @@ def _update_context(context, postdata):
 def database_rsd_converter(input_dict):
     dump = input_dict['dump'] == 'true'
     rsd = RSDConverter(input_dict['context'], discr_intervals=input_dict['discr_intervals'] or {})
-    return {'examples' : rsd.all_examples(), 'bk' : rsd.background_knowledge()}
+    return {'examples': rsd.all_examples(), 'bk': rsd.background_knowledge()}
 
 
 def database_aleph_converter(input_dict):
@@ -73,42 +75,45 @@ def database_aleph_converter(input_dict):
     target_att_val = input_dict['target_att_val']
     if not target_att_val:
         raise Exception('Please specify a target attribute value.')
-    aleph = AlephConverter(input_dict['context'], target_att_val=target_att_val, discr_intervals=input_dict['discr_intervals'] or {})
-    return {'pos_examples' : aleph.positive_examples(), 'neg_examples' : aleph.negative_examples(), 'bk' : aleph.background_knowledge()}
+    aleph = AlephConverter(input_dict['context'], target_att_val=target_att_val,
+                           discr_intervals=input_dict['discr_intervals'] or {})
+    return {'pos_examples': aleph.positive_examples(), 'neg_examples': aleph.negative_examples(),
+            'bk': aleph.background_knowledge()}
 
 
 def database_treeliker_converter(input_dict):
-    treeliker = TreeLikerConverter(input_dict['context'], 
+    treeliker = TreeLikerConverter(input_dict['context'],
                                    discr_intervals=input_dict['discr_intervals'] or {})
-    return {'dataset': treeliker.dataset(), 
+    return {'dataset': treeliker.dataset(),
             'template': treeliker.default_template()}
 
 
 def database_query_to_odt(input_dict):
-    return {'dataset' : None}
+    return {'dataset': None}
 
 
 def database_orange_converter(input_dict):
     context = input_dict['context']
     orange = OrangeConverter(context)
-    return {'target_table_dataset' : orange.target_Orange_table(),'other_table_datasets': orange.other_Orange_tables()}
+    return {'target_table_dataset': orange.target_Orange_table(), 'other_table_datasets': orange.other_Orange_tables()}
 
 
-def database_prd_fct_converter(input_dict):   
+def database_prd_fct_converter(input_dict):
     context = input_dict['context']
     prd_fct = PrdFctConverter(context)
-    
+
     url = tempfile.mkdtemp()
     timenow = int(round(time.time() * 1000))
-    prd_file_url=os.path.join(url,"prdFctTemp%s.prd"%str(timenow))
+    prd_file_url = os.path.join(url, "prdFctTemp%s.prd" % str(timenow))
     with open(prd_file_url, "w") as prd:
-        prd.write( prd_fct.create_prd_file());   
+        prd.write(prd_fct.create_prd_file());
 
-    fct_file_url=os.path.join(url,"prdFctTemp%s.fct"%str(timenow))
+    fct_file_url = os.path.join(url, "prdFctTemp%s.fct" % str(timenow))
     with open(fct_file_url, "w") as fct:
-        fct.write( prd_fct.create_fct_file());      
-       
-    return {'prd_file' : prd_file_url,'fct_file': fct_file_url}
+        fct.write(prd_fct.create_fct_file());
+
+    return {'prd_file': prd_file_url, 'fct_file': fct_file_url}
+
 
 def ilp_map_rsd(input_dict):
     return do_map(input_dict, 'rsd')
@@ -138,4 +143,4 @@ def do_map(input_dict, feature_format, positive_class=None):
     evaluations = domain_map(features, feature_format, train_context,
                              test_context, format=format,
                              positive_class=positive_class)
-    return {'evaluations' : evaluations}
+    return {'evaluations': evaluations}
